package PerlCoreMantainer;
use Mojo::Role;

sub mantaining_perl {
  say "I'm making improvements for Perl..."
}

1;
